
library("KSNR")

source("dataset.R")

imageWidth  = 6  # inches
fontScaling = 0.6

isMajorKey = function(key) (key == toupper(key))

.pitchNamesEnharmonic = c(NA, NA, NA, NA, "-F", NA, NA, NA, "-A", NA, NA, "-C")
getPitchClass = function(pitchName)
{
  pitchName = toupper(pitchName)
  if(pitchName %in% .pitchNamesSharp)
    return(which(.pitchNamesSharp == pitchName) - 1)
  else if(pitchName %in% .pitchNamesFlat)
    return(which(.pitchNamesFlat == pitchName) - 1)
  else if(pitchName %in% .pitchNamesEnharmonic)
    return(which(.pitchNamesEnharmonic == pitchName) - 1)
  else
    stop("Uknown key: ", pitchName)
}

getScaleDegree = function(keyPitchClass, degree)
{
  degreePitchClass = getPitchClass(degree)
  interval = degreePitchClass - keyPitchClass
  if(interval < 0)
    interval = interval + 12
  return(c("1", NA, "2", "b3", "3", "4", NA, "5", "b6", "6", "b7", "7")[interval+1])
}

allData = list()
for(filename in dataset)
{
  cat(filename, "\n")
  currentData = readKSFile(paste("../../Harmony/KSN/", filename, ".ksn", sep=""))
  currentData = currentData[,"Key"]

#   currentMode = isMajorKey(currentData[1])
  tonicPitchClass = rep("", length(currentData))
  tonicPitchClass[1] = "1"
  keyPitchClass = getPitchClass(currentData[1])
  for(ii in 2:length(currentData))
    tonicPitchClass[ii] = getScaleDegree(keyPitchClass, currentData[ii])
  if(any(is.na(tonicPitchClass)))
    stop("NAs produced for keys: ", paste(currentData[is.na(tonicPitchClass)]))
  allData[[length(allData)+1]] = tonicPitchClass
}
